#
# spec file for package perl-IPC-Run3
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name IPC-Run3
Name:           perl-IPC-Run3
Version:        0.49.0
Release:        2.3
%define cpan_version 0.049
#Upstream: SUSE-Public-Domain
License:        Artistic-1.0 OR BSD-2-Clause OR GPL-2.0-or-later
Summary:        Run a subprocess with input/output redirection
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/R/RJ/RJBS/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
Provides:       perl(IPC::Run3) = %{version}
Provides:       perl(IPC::Run3::ProfArrayBuffer) = %{version}
Provides:       perl(IPC::Run3::ProfLogReader) = %{version}
Provides:       perl(IPC::Run3::ProfLogger) = %{version}
Provides:       perl(IPC::Run3::ProfPP) = %{version}
Provides:       perl(IPC::Run3::ProfReporter) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
This module allows you to run a subprocess and redirect stdin, stdout,
and/or stderr to files and perl data structures. It aims to satisfy 99% of
the need for using 'system', 'qx', and 'open3' with a simple, extremely
Perlish API.

Speed, simplicity, and portability are paramount. (That's speed of Perl
code; which is often much slower than the kind of buffered I/O that this
module uses to spool input to and output from the child command.)

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENSE

%changelog
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Sun Jan 21 2024 Tina Müller <timueller+perl@suse.de>
- updated to 0.049
  see /usr/share/doc/packages/perl-IPC-Run3/Changes
  0.049 2024-01-20
  - avoid some uninitialized warnings in ProfLogReader
  - improve errno handling on Windows (thanks, Graham Ollis)
  - avoid leaking fds (thanks, Dan Book)
  - fix typos in docs (thanks, Yoshikazu Sawa and Jakub Wilk)
* Tue Apr 14 2015 coolo@suse.com
- updated to 0.048
  see /usr/share/doc/packages/perl-IPC-Run3/Changes
* Fri Jul 26 2013 coolo@suse.com
- updated to 0.046
  replace a die with a croak (thanks, Mike Doherty)
  typo fixes in documentation (thanks, David Steinbrunner)
* Thu Mar  8 2012 cfarrell@suse.com
- license update: BSD-2-Clause or GPL-2.0+ or Artistic-1.0
  See License
* Mon Feb 27 2012 coolo@suse.com
- updated to 0.045
  skip a test that tickles an OpenBSD bug and hangs the process (thanks,
  BinGOs)
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Fri Sep 17 2010 chris@computersalat.de
- recreated by cpanspec 1.78
- fix deps
- noarch pkg is OK
* Thu Sep 16 2010 larry+opensuse@l2g.to
- New upstream version 0.044. From changelog:
  + ignore user-defined __DIE__ handler in _type (Jeff Lavallee)
  + Added test for __DIE__ handler behavior
* Mon May 24 2010 coolo@novell.com
- do not build noarch
* Thu Mar  4 2010 chris@computersalat.de
- cleanup spec
  o norootforbuild
- fixed deps
- added perl-macros
  o perl_gen_filelist
* Sat Jan 30 2010 larry+opensuse@l2g.to
- Changed the spec for current openSUSE package conventions and to
  make file list stricter
* Mon Jan 25 2010 anicka@suse.cz
- cleaned Requires
